Test Checkbox Events
open | ../tests/html/test_form_events.html |
verifyValue | theCheckbox | off
verifyValue | eventlog |
click | theCheckbox |
verifyValue | theCheckbox | on
verifyValue | eventlog | {focus(theCheckbox)}*
verifyValue | eventlog | *{click(theCheckbox)}*
verifyValue | eventlog | *{change(theCheckbox)}*
type | eventlog |
click | theCheckbox |
verifyValue | theCheckbox | off
verifyValue | eventlog | {focus(theCheckbox)}*
verifyValue | eventlog | *{click(theCheckbox)}*
verifyValue | eventlog | *{change(theCheckbox)}*